==> KPopUp.0.1.4.tgz: KPopUp/menu.h <==
/*
  #############################################################################
  # Diese Datei gehrt zu:                                                    #
  #                                                                           #
  #                  KPOPUP V 0.1.4           (C) Gernot Stocker              #
  #                  ==============                                           #
  #                                                                           #
  #############################################################################
*/
#include <stdio.h>
#include <kapp.h>
#include <qpushbt.h>
#include <qscrbar.h>
#include <qlcdnum.h>
#include <qfont.h>
#include <qlabel.h>
#include <malloc.h>
#include <string.h>
#include <stdio.h>
#include <unistd.h>
#include <qtooltip.h>
#include <qlined.h>
#include <qmlined.h>
#include <qwidget.h>
#include <qdialog.h>
#include <qdatetm.h>

//  --------------------------------------------------------------
//  CHANGE THE PATH , TO THE PATH WHERE THE SMBCLIENT CAN BE FOUND
//  --------------------------------------------------------------

#define SMBPFAD "/usr/local/bin"

//  --------------------------------------------------------------
//  CHANGE THE PATH , TO THE PATH WHERE THE HOSTNAME  CAN BE FOUND
//  --------------------------------------------------------------

#define HOSTNAMEPFAD "/bin"


//          --------------------------------------
//          DON'T CHANGE ANYTHING BELOW THIS MARK!
//          --------------------------------------

class MyWidget : public QWidget
 {
  Q_OBJECT
  public:
     MyWidget(int pzahl,char **param ,QWidget *parent=0, const char *name=0);
     MyWidget();

  public slots:
     void answer();
     void neuespu();
    
  private:
     QPushButton *quit;
     QPushButton *Return;
     QPushButton *NeuPU;
     QLabel *Header, *Kom_Header, *Empf , *Kom_Empf;
     QMultiLineEdit *PUText;
     QTime *Uhrzeit;
     char *Absender;
     char *Empfaenger;
     char *Rechner;
     char *DateiName;
 };

class Antwort : public QDialog
 {
   Q_OBJECT
   public:
      Antwort( QWidget *parent, const char *name );
      QPushButton *ok, *cancel;
      QMultiLineEdit *ptext;
      QLabel *kom_empf, *kom_ptext, *kom_user;
      QComboBox *empf;
      QLineEdit *user;
      void readbrowselist();
      void readhostname();
   public slots:
      void schicken();
 };

==> KPopUp.v1.1b.tgz: KPopUp/menu.h <==
/*
  #############################################################################
  # Diese Datei gehrt zu:                                                    #
  #                                                                           #
  #                  KPOPUP V 1.1B           (C) Gernot Stocker               #
  #                  =============                                            #
  #                                                                           #
  #############################################################################
*/

#include <stdio.h>
#include <kapp.h>
#include <qpushbt.h>
#include <qscrbar.h>
#include <qlcdnum.h>
#include <qfont.h>
#include <qlabel.h>
#include <malloc.h>
#include <string.h>
#include <stdio.h>
#include <unistd.h>
#include <qtooltip.h>
#include <qlined.h>
#include <qmlined.h>
#include <qwidget.h>
#include <qdialog.h>

//  --------------------------------------------------------------
//  CHANGE THE PATH , TO THE PATH WHERE THE SMBCLIENT CAN BE FOUND
//  --------------------------------------------------------------


#define SMBPFAD "/usr/local/bin"


//          --------------------------------------
//          DON'T CHANGE ANYTHING BELOW THIS MARK!
//          --------------------------------------

class MyWidget : public QWidget
 {
  Q_OBJECT
  public:
     MyWidget(int pzahl,char **param ,QWidget *parent=0, const char *name=0);
     MyWidget();

  public slots:
     void answer();
     void neuespu();
    
  private:
     QPushButton *quit;
     QPushButton *Return;
     QPushButton *NeuPU;
     QLabel *PUText, *Header, *Kom_Header, *Empf , *Kom_Empf;
     char *Absender;
     char *Empfaenger;
     char *Rechner;
     char *DateiName;
 };

class Antwort : public QDialog
 {
   Q_OBJECT
   public:
      Antwort( QWidget *parent, const char *name );
      QPushButton *ok, *cancel;
      QMultiLineEdit *ptext;
      QLabel *kom_empf, *kom_ptext, *kom_user;
      QComboBox *empf;
      QLineEdit *user;
      void readbrowselist();
      void readhostname();
   public slots:
      void schicken();
 };
